/*
 * Copyright (C) 2023 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

syntax = "proto2";

package android.os.statsd.wear.media;

import "frameworks/proto_logging/stats/enums/app/wearservices/wearservices_enums.proto";

option java_package = "com.android.os.wear.media";
option java_multiple_files = true;


/**
 * Logs updates of wear media sessions.
 *
 * Logged from :
 * package: vendor/google_clockwork/packages/Media
 */
message MediaSessionUpdated {
  // Package name of the app that owns the media session. (This app is on the
  // paired phone, and not on the watch, hence cannot use uid)
  optional string media_player_package_name = 1;
  // Depicts source of the request. Values : (PHONE/WATCH)
  optional android.app.wearservices.RequestSource source = 2;
  // Version of the media session apk installed in the device.
  optional int64 version_code = 3;
}
